@@ -123,7 +123,8 @@ class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
         """Start the status monitoring thread for the given status object."""
         self._status_thread = thread = TyphosStatusThread(
             status, start_delay=self._min_visible_operation,
-            timeout=timeout
+            timeout=timeout,
+            parent=self,
         )
         thread.status_started.connect(self.move_changed)
         thread.status_finished.connect(self._status_finished)
@@ -224,7 +225,8 @@ class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
     def stop(self):
         """Stop device"""
         for device in self.devices:
-            device.stop()
+            # success=True means expected stop
+            device.stop(success=True)
 
     @QtCore.Slot()
     def clear_error(self):
